/*
 * $Header: /home/cvspublic/jakarta-commons-sandbox/resources/src/test/org/apache/commons/resources/MessagesTestCase.java,v 1.4 2003/03/19 19:02:07 dgraham Exp $
 * $Revision: 1.4 $
 * $Date: 2003/03/19 19:02:07 $
 *
 * ====================================================================
 *
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "The Jakarta Project", "Commons", and "Apache Software
 *    Foundation" must not be used to endorse or promote products derived
 *    from this software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache"
 *    nor may "Apache" appear in their names without prior written
 *    permission of the Apache Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */


package org.apache.commons.resources;


import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.apache.commons.resources.impl.ResourceBundleResourcesFactory;


/**
 * <p>Unit tests for
 * <code>org.apache.commons.resources.Messages</code>.
 * </p>
 *
 * @author Craig R. McClanahan
 * @version $Revision: 1.4 $ $Date: 2003/03/19 19:02:07 $
 */

public class MessagesTestCase
    extends TestCase {


    // ----------------------------------------------------- Instance Variables


    // Configuration value for our resource bundles
    protected static final String CONFIG = "org.apache.commons.resources.impl.TestResources";

    // Logical name of the Resources instance to be created
    protected static final String NAME = "name";


    // The ResourcesFactory to use for acquiring the Resources
    protected ResourcesFactory factory = null;


    // The Resources instance containing our messages
    protected Resources resources = null;

    // The Messages instance to be tested
    protected Messages messages = null;


    // ----------------------------------------------------------- Constructors


    public MessagesTestCase(String name) {
        super(name);
    }


    // --------------------------------------------------- Overall Test Methods


    // Set up instance variables required by this test case
    public void setUp() throws Exception {
        factory = new ResourceBundleResourcesFactory();
        resources = factory.getResources(NAME, CONFIG);
        messages = new Messages(resources);
    }

    // Return the tests included in this test suite
    public static Test suite() {
        return (new TestSuite(MessagesTestCase.class));
    }

    // Tear down the instance variables required by this test case
    public void tearDown() {
        messages = null;
        resources = null;
        factory = null;
    }


    // ------------------------------------------------ Individual Test Methods


    // Test the use of the shortcut getMessages() method
    public void testLocal() {
        String message = null;
        Messages local =
            Messages.getMessages("org.apache.commons.resources.impl.LocalStrings");
        assertNotNull("Local messages found", local);
        message = local.getMessage("local.message");
        assertEquals("Correct individual message",
                     "[Local] REPLACE {0} WITH {1}",
                     message);
        message = local.getMessage("local.message", "abc", "def");
        assertEquals("Correct replaced message",
                     "[Local] REPLACE abc WITH def",
                     message);
        message = local.getMessage("local.missing");
        assertEquals("Correct missing message",
                     "???local.missing???",
                     message);
    }


    // Test the ability to retrieve messages with replacements
    public void testMessages() {
        String message = null;
        message = messages.getMessage("test.message");
        assertEquals("Correct individual message",
                     "[Base] REPLACE {0} WITH {1}",
                     message);
        message = messages.getMessage("test.message", "abc", "def");
        assertEquals("Correct replaced message",
                     "[Base] REPLACE abc WITH def",
                     message);
        message = messages.getMessage("test.missing");
        assertEquals("Correct missing message",
                     "???test.missing???",
                     message);
    }


    // Test the characteristics of a newly created instance
    public void testPristine() {
        assertNotNull(messages);
        assertTrue("Correct wrapped resources",
                   resources == messages.getResources());
    }


}
